#
# spec file for package python-gvm-tools
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global skip_python39 1
Name:           python-gvm-tools
Version:        24.1.0
Release:        1.1
Summary:        Tools to control a GSM/GVM over GMP or OSP
License:        GPL-3.0-or-later
URL:            https://github.com/greenbone/gvm-tools/
Source:         https://github.com/greenbone/gvm-tools/archive/v%{version}.tar.gz#/gvm-tools-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-gvm >= 23.4.2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-gvm >= 23.4.2}
# /SECTION
%python_subpackages

%description
The Greenbone Vulnerability Management Tools gvm-tools are a collection
of tools that help with remote controlling a Greenbone Security Manager
(GSM) appliance and its underlying Greenbone Vulnerability Manager (GVM).
The tools aid in accessing the communication protocols GMP (Greenbone
Management Protocol) and OSP (Open Scanner Protocol).

This module is comprised of interactive and non-interactive clients.
The programming language Python is supported directly for interactive
scripting. But it is also possible to issue remote GMP/OSP commands
without programming in Python.

%prep
%setup -q -n gvm-tools-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/gvm-cli
%python_clone -a %{buildroot}%{_bindir}/gvm-pyshell
%python_clone -a %{buildroot}%{_bindir}/gvm-script
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative gvm-cli gvm-pyshell gvm-script

%postun
%python_uninstall_alternative gvm-cli

%check
%{python_expand find -name '*.snap' | xargs rm
export PYTHONPATH=%{buildroot}%{$python_sitelib}
export PYTHONDONTWRITEBYTECODE=1
py.test-%{$python_version} -vv --ignore-glob=_build.*
}

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/gvm-cli
%python_alternative %{_bindir}/gvm-pyshell
%python_alternative %{_bindir}/gvm-script
%{python_sitelib}/gvmtools
%{python_sitelib}/gvm_tools-%{version}*-info

%changelog
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 24.1.0:
  * New create-consolidated-report container opts
* Mon Dec 18 2023 Dirk Müller <dmueller@suse.com>
- update to 23.11.0:
  * Support for specifying task type
  * Use function to calculate timestamps
  * Do not truncate operating system names
  * Filter for correct target
- update to 23.10.0:
  * Auto-merge workflow, to enable squash auto-merge in open PRs
  * Improve application-detection requests
  * Group dependabot updates
  * Fix param use in generate-random-reports
  * Fix getting hosts in application-detection
  * Remove superfluous output from check-gmp
- update to 23.9.0:
  * Allow to auto re-build the docs on changes via livehtml
  * Add installation instructions using pipx because of PEP 668
  * CERT-Bund Advisory script, parsing reports to CSV (#964)
  * Drop support for Python 3.7 and 3.8
  * Remove obsolete project files
  * Convert docs to use markdown formatting
  * Update copyright year in README
  * Adjust docker image for Debian Bookworm
  * Use generic reusable workflows
  * Create conventional commits for dependabot
  * Remove `cache: "true"` input (#1004)
  * Fix conventional commits workflow
  * Set permissions for conventional commits workflow
* Tue Aug  1 2023 Markéta Machová <mmachova@suse.com>
- update to 23.4.0
  * Support Python 3.11
  * Auto-allow host for SSH connection
* Tue Feb 21 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 23.2.0
  * Added --with-descriptions and host details source types to
    generate-random-reports.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update  to 22.9.0
  * Changelog created for release to 22.9.0
  * Fix: Consolidated Report script finds last report in time period now (#771)
  * Bump bcrypt from 3.2.2 to 4.0.0
  * Bump urllib3 from 1.26.11 to 1.26.12
  * Change: Don't use a pip cache within the container build
  * Bump charset-normalizer from 2.1.0 to 2.1.1 (#767)
  * Bump pygments from 2.12.0 to 2.13.0
  * Bump coverage from 6.4.3 to 6.4.4
  * Bump autohooks from 22.8.0 to 22.8.1
  * Bump github/codeql-action from 1 to 2
  * Bump actions/checkout from 2 to 3
  * Bump actions/setup-python from 2 to 4
  * Add: Update GitHub actions via dependabot too
  * Add dockerignor file for a cleaner container build context
  * Remove unnecessary installation of poetry in container workflow
  * Try to fix poetry issue not being able to find python
  * Update Dockerfile
  * Update container.yml
  * Update container.yml
  * Update container.yml
  * Add: Build container image for gvm-tools
  * Update and improve docs
  * Change: Update links and terms in README and docs
  * Add: Deploy docs to GitHub pages too
  * Normalize strings for gmp scripts too
  * Change: Enable string normalization with black
  * Sort all imports with isort
  * Change: Add autohooks-plugin-isort for import sorting
  * Change: Use greater or equal then for dependencies with calver
* Thu Feb 17 2022 pgajdos@suse.com
- version update to 21.10.0
  Using traceback to print the full error traceback, when a script fails ... db5a7c9
  Fixing and refactoring the update-task-target script. [#544] 8431844
  Fixing some scripts that use Gmp.types... [#535] d7f7eb5
  Fixed the GMP authentication for gvm-cli. #472
  etc. see https://github.com/greenbone/gvm-tools/releases
* Wed Aug 25 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6 or 3.9 due to python-python-gvm.
* Mon Oct 26 2020 Benjamin Greiner <code@bnavigator.de>
- Kill dephell dependency
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.10.1
  Changed
  * Fixed send-schedule.gmp.py script, because <timezone_abbrev>
    has been removed from Schedules, using instead.
  * Fixed send-targets.gmp.py script, because alive_test needs to
    be from AliveTest enum in create_target function.
  * Added gmpv20.08 support to the scan-new-system.gmp.py script,
    as create_target requires an argument port_range or
    port_list_id now.
  * Using the --log argument is not casesensitive anymore. Use the
    lower-case or upper-case loglevel as the argument now.
  Fixed
  * Fixed the check-gmp.gmp.py script, as it was not compatible to
    Python 3.5 anymore.
  * Fixed the check-gmp.gmp.py script: results have not been
    loaded with -F host -T task --status and probably some other
    cases. Added details=True to the command that requests the
    report.
  * Fixed the pdf-report.gmp.py script. Joining the Content of the
    tag was not the correct way here ... we needed the tail of the
    <report_format> tag ...
  Removed
  * Removed gvm.version module in favor of using pontos.version
- Temporary disable source verification (upstream messed it up)
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix signature verification by using github archive
* Tue Aug 11 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.1.0
